@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .operation_metadata import OperationMetadata
+from .operation_metadata import (
+    OperationMetadata,
+)
 
 __all__ = ("OperationMetadata",)
